@@ -2,12 +2,11 @@
 # -*- coding: utf-8 -*-
 
 
-from pdf2docx.reader import Reader
-from pdf2docx.writer import Writer
+from pdf2docx.converter import Converter
 
 
 def parse(pdf_file, docx_file, start=0, end=None, pages=[]):
-    ''' Run the pdf2docx parser
+    ''' Run the pdf2docx parser.
     
         Args:
             pdf_file (str) : PDF filename to read from
@@ -17,30 +16,57 @@ def parse(pdf_file, docx_file, start=0, end=None, pages=[]):
             pages (list)   : range of pages
     '''
 
-    pdf = Reader(pdf_file)
-    docx = Writer()
+    cv = Converter(pdf_file, docx_file)
 
     # parsing arguments
-    pdf_len = len(pdf)
+    pdf_len = len(cv)
     if pages: 
-        pdf_pages = [pdf[int(x)] for x in pages]
+        pdf_pages = [cv[int(x)] for x in pages]
     else:
         end = end or pdf_len
-        pdf_pages = pdf[int(start):int(end)]
+        pdf_pages = cv[int(start):int(end)]
 
     # process page by page
     for page in pdf_pages:
         print(f"Processing {page.number}/{pdf_len-1}...")
-        # parse layout
-        layout = pdf.parse(page)        
-        # create docx
-        docx.make_page(layout)
+        cv.parse(page).make_page()
 
-    # save docx, close pdf
-    docx.save(docx_file)
-    pdf.close()
+    # close pdf
+    cv.close()
     
 
+def extract_tables(pdf_file, start=0, end=None, pages=[]):
+    ''' Extract table content from pdf pages.
+    
+        Args:
+            pdf_file (str) : PDF filename to read from
+            start (int)    : first page to process, starting from zero
+            end (int)      : last page to process, starting from zero
+            pages (list)   : range of pages
+    '''
+
+    cv = Converter(pdf_file)
+
+    # parsing arguments
+    pdf_len = len(cv)
+    if pages: 
+        pdf_pages = [cv[int(x)] for x in pages]
+    else:
+        end = end or pdf_len
+        pdf_pages = cv[int(start):int(end)]
+
+    # process page by page
+    tables = []
+    for page in pdf_pages:
+        print(f"Processing {page.number}/{pdf_len-1}...")
+        page_tables = cv.extract_tables(page)
+        tables.extend(page_tables)
+
+    cv.close()
+
+    return tables
+
+
 def main():
     import fire
     fire.Fire(parse)
